pub struct StatsRequest {
pub body: Vec<u8>,
pub headers: HeaderMap,
pub compression: CompressionStrategy,
pub endpoint: Endpoint,
pub retry: RetryStrategy,
}Expand description
A fully-built HTTP request ready to be sent by the StatsExporter.
The exporter is agnostic to how the body was produced: the agent and
agentless destinations each build their own StatsRequest with the
appropriate encoding, headers, compression, and retry strategy.
Fields
body: Vec<u8>headers: HeaderMapcompression: CompressionStrategyendpoint: Endpointretry: RetryStrategyAuto Trait Implementations
impl !Freeze for StatsRequest
impl RefUnwindSafe for StatsRequest
impl Send for StatsRequest
impl Sync for StatsRequest
impl Unpin for StatsRequest
impl UnsafeUnpin for StatsRequest
impl UnwindSafe for StatsRequest